<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Cobalt\Sources;

use JFactory;
use JLoader;
use JModelLegacy;
use Nextend\Framework\Database\Database;
use Nextend\Framework\Filesystem\Filesystem;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\Select\Filter;
use Nextend\Framework\Form\Element\Text;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3\Generator\AbstractGeneratorGroup;
use Nextend\SmartSlider3\Platform\Joomla\ImageFallback;
use Nextend\SmartSlider3Pro\Generator\Joomla\Cobalt\Elements\CobaltCategories;
use Nextend\SmartSlider3Pro\Generator\Joomla\Cobalt\Elements\CobaltTypes;
use Url;

class CobaltRecords extends AbstractGenerator {

    private $section_id = false;

    protected $layout = 'article';

    public function __construct(AbstractGeneratorGroup $group, $name, $label, $section_id = false) {
        parent::__construct($group, $name, $label);
        $this->section_id = $section_id;
    }

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'Cobalt');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'Cobalt generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');
        new CobaltTypes($source, 'cobaltrecordssourcetype', n2_('Type'));
        new CobaltCategories($source, 'cobaltrecordssourcecategory', n2_('Category'), 0, array(
            'sectionId' => $this->section_id
        ));

        $limit = $filterGroup->createRow('limit-row');
        new Text($limit, 'cobaltrecordssourcelanguage', n2_('Language'), '*');
        new Text($limit, 'cobaltrecordssourceuserid', n2_('User ID'), '');
        new Filter($limit, 'cobaltrecordssourcefeatured', n2_('Featured'), 0);
        new Filter($limit, 'cobaltrecordssourcepublished', n2_('Published'), 1);

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'cobaltrecordsorder', 'rec.ctime|*|desc', array(
            'options' => array(
                ''             => n2_('None'),
                'rec.title'    => n2_('Title'),
                'rec.featured' => n2_('Featured'),
                'rec.ordering' => n2_('Ordering'),
                'rec.hits'     => n2_('Hits'),
                'rec.ctime'    => n2_('Creation time'),
                'rec.mtime'    => 'Modification time'
            )
        ));
    }

    protected function _getData($count, $startIndex) {
        $helper = JPATH_SITE . '/components/com_cobalt/library/tws/php/helper.php';
        if (Filesystem::fileexists($helper)) {
            require_once($helper);
        }

        $category = array_map('intval', explode('||', $this->data->get('cobaltrecordssourcecategory', '')));

        $query = 'SELECT ';

        $query .= 'rec.id ';

        $query .= 'FROM #__js_res_record AS rec ';

        $query .= 'LEFT JOIN #__js_res_record_category AS cat ON cat.record_id = rec.id ';

        $where = array('rec.section_id = \'' . $this->section_id . '\' ');

        if (!in_array(0, $category) && count($category) > 0) {
            $where[] = 'cat.catid IN (' . implode(',', $category) . ') ';
        }

        $type    = intval($this->data->get('cobaltrecordssourcetype', 0));
        $where[] = 'rec.type_id = \'' . $type . '\' ';


        $sourceuserid = intval($this->data->get('cobaltrecordssourceuserid', ''));
        if ($sourceuserid) {
            $where[] = ' rec.user_id = ' . $sourceuserid . ' ';
        }

        switch ($this->data->get('cobaltrecordssourcepublished', 1)) {
            case 1:
                $where[] = ' rec.published = 1 ';
                break;
            case -1:
                $where[] = ' rec.published = 0 ';
                break;
        }

        switch ($this->data->get('cobaltrecordssourcefeatured', 0)) {
            case 1:
                $where[] = ' rec.featured = 1 ';
                break;
            case -1:
                $where[] = ' rec.featured = 0 ';
                break;
        }

        $language = $this->data->get('cobaltrecordssourcelanguage', '*');
        if ($language && $language != '*') {
            $where[] = ' rec.langs = ' . Database::quote($language) . ' ';
        }
        if (count($where) > 0) {
            $query .= 'WHERE ' . implode(' AND ', $where) . ' ';
        }

        $order = Common::parse($this->data->get('cobaltrecordsorder', 'rec.title|*|asc'));
        if ($order[0]) {
            $query .= 'ORDER BY ' . $order[0] . ' ' . $order[1] . ' ';
        }

        $query .= 'LIMIT ' . $startIndex . ', ' . $count;

        $ids = Database::queryAll($query);
        require_once JPATH_SITE . '/components/com_cobalt/models/form.php';

        jimport('joomla.application.component.modellegacy');

        JLoader::import('record', JPATH_SITE . '/components/com_cobalt/models');


        $model = JModelLegacy::getInstance('record', 'CobaltModel');

        $sectionModel = JModelLegacy::getInstance('section', 'CobaltModel');

        $categoryModel = JModelLegacy::getInstance('category', 'CobaltModel');

        $data = array();
        foreach ($ids AS $id) {
            $modelItem = $model->getItem($id['id']);
            JFactory::getApplication()->input->set('id', $modelItem->id);
            $rec = $model->_prepareItem($modelItem);

            $user     = JFactory::getUser($rec->user_id);
            $section  = $sectionModel->getItem($rec->section_id);
            $category = $categoryModel->getItem($rec->section_id);

            $r = array(
                'title'            => $rec->title,
                'url'              => $rec->url,
                'url_label'        => n2_('View record'),
                'hits'             => $rec->hits,
                'created_by_alias' => $user->get('name'),
                'section_title'    => $section->name,
                'section_url'      => Url::records($section),
                'category_title'   => $category->title,
                'category_url'     => Url::records($section, $category),
                'type_title'       => $rec->type_name,
                'id'               => $rec->id,
                'created_by_id'    => $rec->user_id,
                'section_id'       => $rec->section_id,
                'category_id'      => $rec->category_id,
                'type_id'          => $rec->type_id
            );
            if (empty($r['created_by_alias'])) {
                $r['created_by_alias'] = 'Guest';
            }
            if (is_array($rec->fields_by_id) && count($rec->fields_by_id) > 0) {
                $fields = array();
                foreach ($rec->fields_by_id AS $id => $field) {
                    $r_name   = 'extra' . $id . '_' . preg_replace("/\W|_/", "", $field->getLabelName());
                    $fields[] = $r[$r_name] = $field->result;
                }
                $r['image'] = $r['thumbnail'] = ImageFallback::fallback(array(), $fields);
            }
            if (is_array($rec->fields) && count($rec->fields) > 0) {
                foreach ($rec->fields AS $key => $value) {
                    if (is_array($value) && count($value) > 0) {
                        foreach ($value AS $vkey => $vvalue) {
                            if (is_array($vvalue) && count($vvalue) > 0) {
                                foreach ($vvalue AS $vvkey => $vvvalue) {
                                    $r['field_' . $key . '_' . $vkey . '_' . $vvkey] = $vvvalue;
                                }
                            } else {
                                $r['field_' . $key . '_' . $vkey] = $vvalue;
                            }
                        }
                    } else {
                        $r['field_' . $key] = $value;
                    }
                }
            }
            $data[] = $r;
        }

        return $data;
    }
}