<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Jauction\Sources;

use JRoute;
use Nextend\Framework\Database\Database;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\Select\Filter;
use Nextend\Framework\Form\Joomla\Element\Select\MenuItems;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3\Platform\Joomla\ImageFallback;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jauction\Elements\JauctionCategories;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jauction\Elements\JauctionLanguages;

class JauctionAuctions extends AbstractGenerator {

    protected $layout = 'article';

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'JAuction');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'JAuction generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');

        new JauctionCategories($source, 'sourcecategories', n2_('Category'), 0, array(
            'isMultiple' => true
        ));

        $limit = $filterGroup->createRow('limit-row');
        new Filter($limit, 'sourcefeatured', n2_('Featured'), 0);
        new Filter($limit, 'sourceauto', n2_('Auto'), 0);
        new Filter($limit, 'sourceprivate', n2_('Private'), 0);

        new JauctionLanguages($limit, 'sourcelanguage', n2_('Language'), 0);
        new MenuItems($limit, 'itemid', n2_('Menu item (item ID)'), 0);

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'productsorder', 'pn.created|*|desc', array(
            'options' => array(
                ''            => n2_('None'),
                'pt.name'     => n2_('Product name'),
                'pn.created'  => n2_('Creation time'),
                'pn.modified' => n2_('Modification time'),
                'rand()'      => n2_('Random')
            )
        ));
    }

    protected function _getData($count, $startIndex) {
        $where = array(
            'pn.publish = 1',
            "pn.prodtypid = (SELECT prodtypid FROM #__product_type WHERE namekey = 'auction')"
        );

        $category = array_map('intval', explode('||', $this->data->get('sourcecategories', '')));
        if (!in_array(0, $category) && count($category) > 0) {
            $where[] = 'pn.pid IN (SELECT pid FROM #__productcat_product WHERE catid IN(' . implode(',', $category) . ')) ';
        }

        $language = $this->data->get('sourcelanguage', '0');
        if ($language != 0) {
            $where[] = 'pt.lgid = ' . $language;
        }

        switch ($this->data->get('sourcefeatured', '0')) {
            case 1:
                $where[] = 'pn.featured = 1';
                break;
            case -1:
                $where[] = 'pn.featured = 0';
                break;
        }

        switch ($this->data->get('sourceauto', '0')) {
            case 1:
                $where[] = 'pa.auto = 1';
                break;
            case -1:
                $where[] = 'pa.auto = 0';
                break;
        }

        switch ($this->data->get('sourceprivate', '0')) {
            case 1:
                $where[] = 'pa.private = 1';
                break;
            case -1:
                $where[] = 'pa.private = 0';
                break;
        }

        $o     = '';
        $order = Common::parse($this->data->get('productsorder', 'pn.created|*|desc'));
        if ($order[0]) {
            $o = ' ORDER BY ' . $order[0] . ' ' . $order[1] . ' ';
        }

        $query = "SELECT pn.pid, pn.longitude, pn.latitude, pn.location, pn.namekey, pn.price,
                  pt.description, pt.name, pt.introduction, pt.seotitle, pt.seodescription, pt.seokeywords,
                  pa.startingbid, pa.reservebid, pa. biddingstart, pa. biddingend,
                  (SELECT name FROM #__file_node WHERE filid IN (SELECT filid FROM #__product_images WHERE pid = pn.pid AND ordering = 1) LIMIT 1) AS image,
                  (SELECT type FROM #__file_node WHERE filid IN (SELECT filid FROM #__product_images WHERE pid = pn.pid AND ordering = 1) LIMIT 1) AS type
                  FROM #__product_node AS pn LEFT JOIN #__product_trans AS pt ON pn.pid = pt.pid LEFT JOIN #__product_auction AS pa ON pn.pid = pa.pid WHERE " . implode(' AND ', $where) . $o . " LIMIT " . $startIndex . ", " . $count;

        $result = Database::queryAll($query);

        $itemID = $this->data->get('itemid', '0');
        if ($itemID == '0') {
            $itemID = '';
        } else {
            $itemID = '&Itemid=' . $itemID;
        }

        $data = array();
        foreach ($result AS $product) {
            $r      = array(
                'title'              => $product['name'],
                'description'        => $product['description'],
                'introduction'       => $product['introduction'],
                'image'              => ImageFallback::fallback(array(
                    !empty($product['image']) ? 'joobi/user/media/images/products/' . $product['image'] . '.' . $product['type'] : '',
                ), array(
                    @$product['description']
                )),
                'thumbnail'          => !empty($product['image']) ? '$/joobi/user/media/images/products/thumbnails/' . $product['image'] . '.' . $product['type'] : '',
                'oversize_image'     => !empty($product['image']) ? '$/joobi/user/media/images/products/oversize/' . $product['image'] . '.' . $product['type'] : '',
                'url'                => JRoute::_('index.php?option=com_jauction&controller=catalog&task=show&eid=' . $product['pid'] . $itemID),
                'startingbid'        => $product['startingbid'],
                'roundedstartingbid' => round(floatval($product['startingbid']), 2),
                'reservebid'         => $product['reservebid'],
                'roundedreservebid'  => round(floatval($product['reservebid']), 2),
                'buynow'             => $product['price'],
                'roundedbuynow'      => round(floatval($product['price']), 2),
                'biddingstart'       => date('Y-m-d H:i', $product['biddingstart']),
                'biddingend'         => date('Y-m-d H:i', $product['biddingend']),
                'location'           => $product['location'],
                'longitude'          => $product['longitude'],
                'latitude'           => $product['latitude'],
                'sku'                => $product['namekey'],
                'seotitle'           => $product['seotitle'],
                'seodescription'     => $product['seodescription'],
                'seokeywords'        => $product['seokeywords'],
                'id'                 => $product['pid']
            );
            $data[] = $r;
        }

        return $data;
    }
}