<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Jcart\Sources;

use Config;
use ControllerStartupSeoUrl;
use JFactory;
use JURI;
use Nextend\Framework\Database\Database;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\Select\Filter;
use Nextend\Framework\Form\Element\Text\Number;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3\Platform\Joomla\ImageFallback;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jcart\Elements\JcartCategories;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jcart\Elements\JcartLanguages;
use stdClass;
use Url;

if (!class_exists("Config")) {
    require_once(JPATH_ROOT . DIRECTORY_SEPARATOR . 'components' . DIRECTORY_SEPARATOR . 'com_opencart' . DIRECTORY_SEPARATOR . 'config.php');
}

if (!class_exists("Action")) {
    require_once(JPATH_ROOT . DIRECTORY_SEPARATOR . 'components' . DIRECTORY_SEPARATOR . 'com_opencart' . DIRECTORY_SEPARATOR . 'system' . DIRECTORY_SEPARATOR . 'startup.php');
}

if (!class_exists("ControllerStartupSeoUrl")) {
    require_once(JPATH_ROOT . DIRECTORY_SEPARATOR . 'components' . DIRECTORY_SEPARATOR . 'com_opencart' . DIRECTORY_SEPARATOR . 'catalog' . DIRECTORY_SEPARATOR . 'controller' . DIRECTORY_SEPARATOR . 'startup' . DIRECTORY_SEPARATOR . 'seo_url.php');
}

class N2DBConnectorJCart {

    static function escape($var) {
        return JFactory::getDbo()
                       ->escape($var);
    }

    public function query($query) {
        $dbResult = Database::queryRow($query);
        $result   = new stdClass();

        $result->num_rows = count($dbResult);
        if (!empty($dbResult)) {
            $result->rows = $dbResult;
            foreach ($dbResult AS $key => $value) {
                $result->row[$key] = $value;
            }
        } else {
            $result->rows           = null;
            $result->row['keyword'] = null;
            $result->row['name']    = null;
        }

        return $result;
    }
}

class N2ControllerStartupSeoUrl extends ControllerStartupSeoUrl {

    public $config;
    public $db;
    public $session;

    public function __construct() {
        $this->config = new Config();
        global $joomla_db;
        if (empty($joomla_db)) {
            $joomla_db = JFactory::getDBO();
        }
        global $jCartSmartSliderLanguage;
        if (empty($jCartSmartSliderLanguage)) {
            $jCartSmartSliderLanguage = 0;
        }
        $this->config->set('config_language_id', intval($jCartSmartSliderLanguage));

        $this->db = new N2DBConnectorJCart();

        $this->session->data['language'] = '';
    }
}

class JcartProducts extends AbstractGenerator {

    protected $layout = 'product';

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'JCart');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'JCart generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');
        new JcartCategories($source, 'jcartsourcecategories', n2_('Category'), 0, array(
            'isMultiple' => true
        ));

        $limit = $filterGroup->createRow('limit-row');
        new Filter($limit, 'jcartsourceinstock', n2_('In stock'), 0);
        new Filter($limit, 'jcartsourceavailable', n2_('Available by date'), 0);
        new Filter($limit, 'jcartsourceshipping', n2_('Requires shipping'), 0);
        new JcartLanguages($limit, 'jcartsourcelanguage', n2_('Language'), 0);
        new Number($limit, 'jcartsourceminimum', n2_('Min order quantity'), 0);

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'jcartorder', 'p.date_added|*|desc', array(
            'options' => array(
                ''                => n2_('None'),
                'pd.name'         => n2_('Product name'),
                'p.sort_order'    => n2_('Ordering'),
                'p.viewed'        => n2_('Viewed'),
                'p.price'         => n2_('Price'),
                'p.date_added'    => n2_('Creation time'),
                'p.date_modified' => n2_('Modification time')
            )
        ));
    }

    protected function _getData($count, $startIndex) {
        if (!defined('HTTP_SERVER')) {
            define('HTTP_SERVER', JURI::base());
        }

        $categories = array_map('intval', explode('||', $this->data->get('jcartsourcecategories', '0')));
        $where      = array('p.status = 1');

        if (!in_array(0, $categories) && count($categories) > 0) {
            $where[] = 'ptc.category_id IN (' . implode(',', $categories) . ') ';
        }

        switch ($this->data->get('jcartsourceinstock', 0)) {
            case 1:
                $where[] = ' p.quantity > 0 ';
                break;
            case -1:
                $where[] = ' p.quantity = 0 ';
                break;
        }

        $jNow = JFactory::getDate();
        $date = $jNow->format('Y-m-d');

        switch ($this->data->get('jcartsourceavailable', 0)) {
            case 1:
                $where[] = " p.date_available <= '" . $date . "'";
                break;
            case -1:
                $where[] = " p.date_available > '" . $date . "'";
                break;
        }

        $language = $this->data->get('jcartsourcelanguage', 0);
        if ($language != 0) {
            $where[] = ' pd.language_id  = ' . $language;
        }
        global $jCartSmartSliderLanguage;
        $jCartSmartSliderLanguage = $language;

        switch ($this->data->get('jcartsourceshipping', 0)) {
            case 1:
                $where[] = ' p.shipping = 1 ';
                break;
            case -1:
                $where[] = ' p.shipping = 0 ';
                break;
        }

        $minimum = $this->data->get('jcartsourceminimum', 0);
        if ($minimum != 0) {
            $where[] = ' p.minimum  >= ' . $minimum;
        }

        $query = "SELECT pd.name, pd.description, pd.tag, pd.meta_title, pd.meta_description, pd.meta_keyword,
                    p.image, p.price, p.weight, p.length, p.width, p.height, p.model, p.sku, p.upc, p.ean, p.jan, p.isbn, p.mpn, p.location, p.points, p.quantity, p.product_id,
                    cd.name AS category_name, cd.description AS category_description, cd.category_id
                    FROM " . DB_PREFIX . "product_to_category AS ptc
                    LEFT JOIN " . DB_PREFIX . "product AS p ON ptc.product_id = p.product_id
                    LEFT JOIN " . DB_PREFIX . "product_description AS pd ON p.product_id = pd.product_id
                    LEFT JOIN " . DB_PREFIX . "category_description AS cd ON ptc.category_id = cd.category_id
                    WHERE " . implode(' AND ', $where) . ' GROUP BY ptc.product_id';

        $order = Common::parse($this->data->get('jcartorder', 'p.date_added|*|desc'));
        if ($order[0]) {
            $query .= ' ORDER BY ' . $order[0] . ' ' . $order[1] . ' ';
        }

        $query .= 'LIMIT ' . $startIndex . ', ' . $count;

        $result = Database::queryAll($query);

        $query    = "SELECT * FROM " . DB_PREFIX . "currency WHERE code = (SELECT value FROM " . DB_PREFIX . "setting WHERE `key` = 'config_currency' LIMIT 1) LIMIT 1";
        $currency = Database::queryRow($query);

        $query = "SELECT rate FROM " . DB_PREFIX . "tax_rate";
        $taxes = Database::queryAll($query);

        $data = array();
        $uri  = \Nextend\Framework\Url\Url::getBaseUri();
        $url  = new Url($uri . '/');

        foreach ($result AS $res) {
            $r = array(
                'title'       => $res['name'],
                'description' => $res['description']
            );

            $r['thumbnail'] = $r['image'] = ImageFallback::fallback(array(
                !empty($res['image']) ? JOOCART_RELATIVE_URL . 'image/' . $res['image'] : ''
            ), array(
                str_replace('../components/com_jcart', 'components/com_jcart', 'components/com_opencart', $res['description'])
            ));

            $baseUrl     = ImageFallback::siteURL();
            $productUrl  = $this->removeItemID($this->changeAnd($url->link('product/product', '&product_id=' . $res['product_id'])));
            $categoryUrl = $this->removeItemID($this->changeAnd($url->link('product/category', '&path=' . $res['category_id'])));

            $seo            = new N2ControllerStartupSeoUrl();
            $seoUrl         = $this->removeItemID($this->changeAnd(@$seo->rewrite($baseUrl . $productUrl)));
            $categorySeoUrl = $this->removeItemID($this->changeAnd(@$seo->rewrite($baseUrl . $categoryUrl)));

            $r += array(
                'seo_url'              => $seoUrl,
                'seo_category_url'     => $categorySeoUrl,
                'url'                  => $productUrl,
                'category_url'         => $categoryUrl,
                'price'                => $this->format($res['price'], $currency),
                'price_without_format' => $this->format($res['price'], $currency, false),
                'weight'               => round($res['weight'], 2),
                'length'               => round($res['length'], 2),
                'width'                => round($res['width'], 2),
                'height'               => round($res['height'], 2),
                'model'                => $res['model'],
                'sku'                  => $res['sku'],
                'upc'                  => $res['upc'],
                'ean'                  => $res['ean'],
                'jan'                  => $res['jan'],
                'isbn'                 => $res['isbn'],
                'mpn'                  => $res['mpn'],
                'location'             => $res['location'],
                'points'               => $res['points'],
                'quantity'             => $res['quantity'],
                'tag'                  => $res['tag'],
                'meta_title'           => $res['meta_title'],
                'meta_description'     => $res['meta_description'],
                'meta_keyword'         => $res['meta_keyword'],
                'category_name'        => $res['category_name'],
                'category_description' => $res['category_description'],
                'category_id'          => $res['category_id'],
                'id'                   => $res['product_id']
            );
            $i = 1;
            foreach ($taxes AS $tax) {
                $price_with_tax = $res['price'] + ($res['price'] * $tax['rate'] / 100);
                $r              += array('price_with_tax' . $i => $this->format($price_with_tax, $currency));
                $i++;
            }

            $data[] = $r;
        }

        return $data;
    }


    private function format($number, $currency = '', $format = true) {
        $symbol_left   = $currency['symbol_left'];
        $symbol_right  = $currency['symbol_right'];
        $decimal_place = $currency['decimal_place'];
        $value         = $currency['value'];

        $amount = $value ? (float)$number * $value : (float)$number;

        $amount = round($amount, (int)$decimal_place);

        if (!$format) {
            return $amount;
        }

        $string = '';

        if ($symbol_left) {
            $string .= $symbol_left;
        }

        $string .= number_format($amount, (int)$decimal_place);

        if ($symbol_right) {
            $string .= $symbol_right;
        }

        return $string;
    }

    private function changeAnd($var) {
        return str_replace('&amp;', '&', $var);
    }

    private function removeItemID($url) {
        return preg_replace('~[?&]Itemid=[^&]*~', '$1', $url);
    }
}
