<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Sources;

use CRoute;
use Nextend\Framework\Database\Database;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\Select\Filter;
use Nextend\Framework\Form\Element\Text;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3\Platform\Joomla\ImageFallback;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Elements\JomsocialCategories;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Elements\JomsocialGroups;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Elements\JomsocialProfiles;

class JomsocialEvents extends AbstractGenerator {

    protected $layout = 'event';

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'Events');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'Jomsocial generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');
        new JomsocialCategories($source, 'jomsocialcategories', n2_('Category'), 0, array(
            'isMultiple' => true
        ));
        new JomsocialGroups($source, 'jomsocialgroups', 'Groups', 0, array(
            'isMultiple' => true
        ));
        new JomsocialProfiles($source, 'jomsocialprofiles', 'Profiles', 0, array(
            'isMultiple' => true
        ));

        $date = $filterGroup->createRow('date-row');
        new Filter($date, 'started', n2_('Started'), 0);
        new Filter($date, 'ended', n2_('Ended'), -1);
        new Text($date, 'dateformat', n2_('Date format'), 'Y-m-d');
        new Text($date, 'timeformat', n2_('Time format'), 'H:i');


        $limit = $filterGroup->createRow('limit-row');
        new Filter($limit, 'invitation', 'Invitation only event', 0);
        new Filter($limit, 'hidden', 'Hidden on list of events', 0);

        new Text($limit, 'location', n2_('Location'), '*');
        new Text($limit, 'userid', n2_('User ID'), '*');

        $featured = $filterGroup->createRow('featured-row');
        new Filter($featured, 'featuredevents', 'Featured events', 0);
        new Filter($featured, 'featuredusers', 'Created by featured users', 0);
        new Filter($featured, 'featuredgroups', 'Created by featured groups', 0);

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'jomsocialorder', 'startdate|*|asc', array(
            'options' => array(
                ''          => n2_('None'),
                'title'     => n2_('Title'),
                'created'   => n2_('Creation time'),
                'startdate' => n2_('Start time'),
                'enddate'   => n2_('End time'),
                'a.summary' => n2_('Title'),
                'hits'      => n2_('Hits'),
                'id'        => 'ID'
            )
        ));
    }

    private function formatDate($datetime, $format) {
        return date($format, strtotime($datetime));
    }

    protected function _getData($count, $startIndex) {

        require_once(JPATH_SITE . '/components/com_community/router.php');

        $where = array(
            "published = 1"
        );

        $category = array_map('intval', explode('||', $this->data->get('jomsocialcategories', '0')));
        if (!in_array('0', $category)) {
            $where[] = 'catid IN (' . implode(',', $category) . ')';
        }

        $group = array_map('intval', explode('||', $this->data->get('jomsocialgroups', '0')));
        if (!in_array('0', $group)) {
            $where[] = 'contentid IN (' . implode(',', $group) . ')';
        }

        $profiles = array_map('intval', explode('||', $this->data->get('jomsocialprofiles', '0')));
        if (!in_array('0', $profiles)) {
            $where[] = 'creator IN (SELECT userid FROM #__community_users WHERE profile_id IN (' . implode(',', $profiles) . '))';
        }

        $today = date('Y-m-d h:i:s', time());

        switch ($this->data->get('started', '0')) {
            case 1:
                $where[] = "startdate < '" . $today . "'";
                break;
            case -1:
                $where[] = "startdate >= '" . $today . "'";
                break;
        }

        switch ($this->data->get('ended', '-1')) {
            case 1:
                $where[] = "enddate < '" . $today . "'";
                break;
            case -1:
                $where[] = "enddate >= '" . $today . "'";
                break;
        }

        switch ($this->data->get('featuredevents', '-1')) {
            case 1:
                $where[] = "id IN (SELECT cid FROM #__community_featured WHERE type = 'events')";
                break;
            case -1:
                $where[] = "id NOT IN (SELECT cid FROM #__community_featured WHERE type = 'events')";
                break;
        }

        switch ($this->data->get('featuredusers', '-1')) {
            case 1:
                $where[] = "creator IN (SELECT cid FROM #__community_featured WHERE type = 'users')";
                break;
            case -1:
                $where[] = "creator NOT IN (SELECT cid FROM #__community_featured WHERE type = 'users')";
                break;
        }

        switch ($this->data->get('featuredgroups', '-1')) {
            case 1:
                $where[] = "contentid IN (SELECT cid FROM #__community_featured WHERE type = 'groups')";
                break;
            case -1:
                $where[] = "contentid NOT IN (SELECT cid FROM #__community_featured WHERE type = 'groups')";
                break;
        }

        switch ($this->data->get('invitation', '-1')) {
            case 1:
                $where[] = "permission = 1";
                break;
            case -1:
                $where[] = "permission = 0";
                break;
        }

        switch ($this->data->get('hidden', '-1')) {
            case 1:
                $where[] = "unlisted = 1";
                break;
            case -1:
                $where[] = "unlisted = 0";
                break;
        }

        $location = $this->data->get('location', '*');
        if ($location != '*' && !empty($location)) {
            $where[] = "location = '" . $location . "'";
        }

        $userid = $this->data->get('userid', '*');
        if ($userid != '*' && !empty($userid)) {
            $where[] = "creator IN (" . $userid . ")";
        }

        $query = "SELECT * FROM #__community_events WHERE " . implode(' AND ', $where) . "  ";

        $order = Common::parse($this->data->get('jomsocialorder', 'startdate|*|asc'));
        if ($order[0]) {
            $query .= 'ORDER BY ' . $order[0] . ' ' . $order[1] . ' ';
        }

        $query .= 'LIMIT ' . $startIndex . ', ' . $count;

        $result = Database::queryAll($query);

        $dateFormat = $this->data->get('dateformat', 'Y-m-d');
        $timeFormat = $this->data->get('timeformat', 'H:i');

        $data = array();
        for ($i = 0; $i < count($result); $i++) {
            $r = array(
                'title'             => $result[$i]['title'],
                'short_description' => $result[$i]['summary'],
                'description'       => $result[$i]['description']
            );

            $r['image'] = $r['thumbnail'] = ImageFallback::fallback(array(
                @$result[$i]['cover']
            ), array(
                $r['description']
            ));

            $r      += array(
                'url'        => CRoute::_('index.php?option=com_community&view=events&task=viewevent&eventid=' . $result[$i]['id']),
                'start_date' => $this->formatDate($result[$i]['startdate'], $dateFormat),
                'start_time' => $this->formatDate($result[$i]['startdate'], $timeFormat),
                'end_date'   => $this->formatDate($result[$i]['enddate'], $dateFormat),
                'end_time'   => $this->formatDate($result[$i]['enddate'], $timeFormat),
                'location'   => $result[$i]['location'],
                'latitude'   => $result[$i]['latitude'],
                'longitude'  => $result[$i]['longitude'],
                'id'         => $result[$i]['id']
            );
            $data[] = $r;
        }

        return $data;
    }
}
