<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Sources;

use CRoute;
use Nextend\Framework\Database\Database;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\Select;
use Nextend\Framework\Form\Element\Select\Filter;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\Framework\ResourceTranslator\ResourceTranslator;
use Nextend\Framework\Url\Url;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3\Platform\Joomla\ImageFallback;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Elements\JomsocialCategories;

class JomsocialGroups extends AbstractGenerator {

    protected $layout = 'article';

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'Groups');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'Jomsocial generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');
        new JomsocialCategories($source, 'jomsocialgroupcategories', n2_('Category'), 0, array(
            'isMultiple' => true
        ));


        $limit = $filterGroup->createRow('limit-row');
        new Filter($limit, 'featured', 'Featured', 0);

        new Select($limit, 'grouptype', n2_('Type'), '0', array(
            'options' => array(
                '-1' => n2_('All'),
                '0'  => n2_('Public'),
                '1'  => n2_('Private')
            )
        ));

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'jomsocialorder', 'created|*|desc', array(
            'options' => array(
                ''             => n2_('None'),
                'name'         => n2_('Name'),
                'created'      => n2_('Creation time'),
                'discusscount' => 'Number of discussions',
                'wallcount'    => 'Number of walls',
                'membercount'  => 'Number of members',
                'hits'         => n2_('Hits'),
                'id'           => 'ID'
            )
        ));
    }

    private function checkImage($url, $image, $fallback = '') {
        if (!empty($image)) {
            return ResourceTranslator::urlToResource($url . '/' . $image);
        } else if (!empty($fallback)) {
            return $fallback;
        } else {
            return '';
        }
    }

    protected function _getData($count, $startIndex) {

        require_once(JPATH_SITE . '/components/com_community/router.php');

        $where = array(
            "published = 1"
        );

        $category = array_map('intval', explode('||', $this->data->get('jomsocialgroupcategories', '0')));
        if (!in_array('0', $category)) {
            $where[] = 'categoryid IN (' . implode(',', $category) . ')';
        }

        switch ($this->data->get('featured', '-1')) {
            case 1:
                $where[] = "id IN (SELECT cid FROM #__community_featured WHERE type = 'groups')";
                break;
            case -1:
                $where[] = "id NOT IN (SELECT cid FROM #__community_featured WHERE type = 'groups')";
                break;
        }

        $grouptype = $this->data->get('grouptype', '-1');
        if ($grouptype != '-1') {
            $where[] = 'approvals = ' . $grouptype;
        }

        $query = "SELECT * FROM #__community_groups WHERE " . implode(' AND ', $where) . " ";

        $order = Common::parse($this->data->get('jomsocialorder', 'created|*|desc'));
        if ($order[0]) {
            $query .= 'ORDER BY ' . $order[0] . ' ' . $order[1] . ' ';
        }

        $query .= 'LIMIT ' . $startIndex . ', ' . $count;

        $result = Database::queryAll($query);

        $root = Url::getBaseUri();

        $data = array();
        for ($i = 0; $i < count($result); $i++) {
            $r = array(
                'title'       => $result[$i]['name'],
                'description' => $result[$i]['description'],
                'summary'     => $result[$i]['summary']
            );

            $r['image'] = ImageFallback::fallback(array(
                @$result[$i]['avatar'],
                @$result[$i]['cover']
            ), array(
                $r['description']
            ));

            $r['thumbnail'] = $this->checkImage($root, $result[$i]['thumb'], $r['image']);

            $r      += array(
                'avatar'    => $this->checkImage($root, $result[$i]['avatar']),
                'cover'     => $this->checkImage($root, $result[$i]['cover']),
                'url'       => CRoute::_('index.php?option=com_community&view=groups&task=viewgroup&groupid=' . $result[$i]['id']),
                'url_label' => n2_('View group'),
                'id'        => $result[$i]['id']
            );
            $data[] = $r;
        }

        return $data;
    }
}
