<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Sources;

use Nextend\Framework\Database\Database;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\Select\Filter;
use Nextend\Framework\Form\Element\Text\Number;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\Framework\ResourceTranslator\ResourceTranslator;
use Nextend\Framework\Url\Url;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Elements\JomsocialEvents;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Elements\JomsocialGroups;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jomsocial\Elements\JomsocialVideotype;

class JomsocialVideos extends AbstractGenerator {

    protected $layout = 'youtube';

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'Videos');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'Jomsocial generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');
        new JomsocialEvents($source, 'jomsocialevents', n2_('Events'), 0, array(
            'isMultiple' => true
        ));
        new JomsocialGroups($source, 'jomsocialgroups', n2_('Groups'), 0, array(
            'isMultiple' => true
        ));


        $limit = $filterGroup->createRow('limit-row');
        new Filter($limit, 'featured', 'Featured', 0);

        $videotypeRow = $filterGroup->createRow('videotype-row');
        new JomsocialVideotype($videotypeRow, 'videotype', n2_('Type'), 'youtube');
        $useridRow = $filterGroup->createRow('userid-row');
        new Number($useridRow, 'userid', n2_('User ID'), '*');

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'jomsocialorder', 'created|*|desc', array(
            'options' => array(
                ''        => n2_('None'),
                'title'   => n2_('Title'),
                'created' => n2_('Creation time'),
                'hits'    => n2_('Hits'),
                'id'      => 'ID'
            )
        ));
    }

    protected function _getData($count, $startIndex) {

        require_once(JPATH_SITE . '/components/com_community/router.php');

        $where = array(
            "published = 1"
        );

        $videoType = $this->data->get('videotype', 'youtube');
        if ($videoType === "0") {
            $videoType = "%";
            $where[]   = "type LIKE '" . $videoType . "'";
        } else {
            $where[] = "type = '" . $videoType . "'";
        }

        $group  = array_map('intval', explode('||', $this->data->get('jomsocialgroups', '0')));
        $events = array_map('intval', explode('||', $this->data->get('jomsocialevents', '0')));

        if (!in_array('0', $group) && !in_array('0', $events)) {
            $where[] = '(groupid IN (' . implode(',', $group) . ') OR eventid IN (' . implode(',', $events) . '))';
        } else if (!in_array('0', $group)) {
            $where[] = 'groupid IN (' . implode(',', $group) . ')';
        } else if (!in_array('0', $events)) {
            $where[] = 'eventid IN (' . implode(',', $events) . ')';
        }

        $userID = $this->data->get('userid', '*');
        if ($userID != '*' && !empty($userID)) {
            $where[] = 'creator IN (' . $userID . ')';
        }

        switch ($this->data->get('featured', '-1')) {
            case 1:
                $where[] = "featured = 1";
                break;
            case -1:
                $where[] = "featured = 0";
                break;
        }

        $query = "SELECT * FROM #__community_videos WHERE " . implode(' AND ', $where) . " ";

        $order = Common::parse($this->data->get('jomsocialorder', 'created|*|desc'));
        if ($order[0]) {
            $query .= 'ORDER BY ' . $order[0] . ' ' . $order[1] . ' ';
        }

        $query .= 'LIMIT ' . $startIndex . ', ' . $count;

        $result = Database::queryAll($query);

        $root = Url::getBaseUri();

        $data = array();
        for ($i = 0; $i < count($result); $i++) {
            $image  = ResourceTranslator::urlToResource($root . '/' . $result[$i]['thumb']);
            $r      = array(
                'title'      => $result[$i]['title'],
                'video_path' => $result[$i]['path'],
                'video_id'   => $result[$i]['video_id'],
                'image'      => $image,
                'thumbnail'  => $image,
                'id'         => $result[$i]['id']
            );
            $data[] = $r;
        }

        return $data;
    }
}
