<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Jreviews\Sources;

use ContentHelperRoute;
use JURI;
use Nextend\Framework\Database\Database;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\Select;
use Nextend\Framework\Form\Element\Text;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\Framework\ResourceTranslator\ResourceTranslator;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3\Platform\Joomla\JoomlaShim;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jreviews\Elements\JreviewsArticles;
use Nextend\SmartSlider3Pro\Generator\Joomla\Jreviews\Elements\JreviewsCategories;


JoomlaShim::loadComContentRoute();

class JreviewsComments extends AbstractGenerator {

    protected $layout = 'article';

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'JReviews');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'JReviews generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');
        new JreviewsCategories($source, 'sourcecategories', n2_('Category'), 0, array(
            'isMultiple' => true
        ));
        new JreviewsArticles($source, 'sourcearticles', n2_('Article'), 0, array(
            'isMultiple' => true
        ));


        $limit = $filterGroup->createRow('limit-row');
        new Select($limit, 'sourcestars', 'Min star rating', 1, array(
            'options' => array(
                ''  => '1',
                '2' => '2',
                '3' => '3',
                '4' => '4',
                '5' => '5'
            )
        ));
        new Text($limit, 'sourcehelpful', 'Min thumbs up number', 0);

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'jreviewsorder', 'jc.created|*|desc', array(
            'options' => array(
                ''                => n2_('None'),
                'jc.created'      => n2_('Creation time'),
                'jc.modified'     => n2_('Modification time'),
                'jc.rating'       => 'Rating',
                'jc.vote_helpful' => 'Thumbs up',
                'jc.vote_total'   => 'Total number of votes',
                'c.hits'          => n2_('Hits')
            )
        ));
    }

    function imageUrl($image) {
        $root = JURI::root();
        if (!empty($image)) {
            return ResourceTranslator::urlToResource($root . $image);
        } else {
            return '';
        }
    }

    protected function _getData($count, $startIndex) {

        $categories = array_map('intval', explode('||', $this->data->get('sourcecategories', '')));
        $articles   = array_map('intval', explode('||', $this->data->get('sourcearticles', '')));

        $where = array(
            'jc.published = 1',
            'jc.mode = \'com_content\''
        );

        $articleWhere = '';
        if (!in_array(0, $articles) && count($articles) > 0) {
            $articleWhere = ' AND asset_id IN (' . implode(',', $articles) . ') ';
        }

        if (!in_array(0, $categories) && count($categories) > 0) {
            $where[] = 'jc.pid IN (SELECT id FROM #__content WHERE asset_id IN (SELECT id FROM #__assets WHERE parent_id IN (' . implode(',', $categories) . '))' . $articleWhere . ')';
        } else if (!in_array(0, $articles) && count($articles) > 0) {
            $where[] = 'jc.pid IN (SELECT id FROM #__content WHERE asset_id IN (' . implode(',', $articles) . '))';
        }

        $stars = $this->data->get('sourcestars', '');
        if (!empty($stars)) {
            $where[] = 'jc.rating >= ' . $stars;
        }

        $helpful = intval($this->data->get('sourcehelpful', ''));
        if (!empty($helpful) && $helpful > 0) {
            $where[] = 'jc.vote_helpful >= ' . $helpful;
        }

        $query = 'SELECT *,jc.title AS comment_title FROM #__jreviews_comments AS jc
                  LEFT JOIN #__content AS c ON jc.pid = c.id
                  WHERE ' . implode(' AND ', $where);

        $order = Common::parse($this->data->get('jreviewsorder', 'jc.created|*|desc'));
        if ($order[0]) {
            $query .= ' ORDER BY ' . $order[0] . ' ' . $order[1] . ' ';
        }

        $query .= ' LIMIT ' . $startIndex . ', ' . $count;

        $result = Database::queryAll($query);

        $data = array();

        foreach ($result as $res) {
            $r = array(
                'title'       => $res['comment_title'],
                'description' => $res['comments']
            );

            $query = 'SELECT media_type, filename, file_extension, rel_path, title, description, embed FROM #__jreviews_media
                      WHERE listing_id = ' . $res['pid'] . ' AND published = 1 AND approved = 1';
            $media = Database::queryAll($query);

            $i = 1;
            foreach ($media as $m) {
                if ($m['media_type'] == 'photo') {
                    $r['photo' . $i] = $this->imageUrl('media/reviews/photos/' . $m['rel_path'] . $m['filename'] . '.' . $m['file_extension']);
                    $i++;
                }
            }

            $article_images = json_decode($res['images']);

            if (isset($r['photo1'])) {
                $r['image'] = $r['photo1'];
            } else if (!empty($article_images->image_intro)) {
                $r['image'] = $this->imageUrl($article_images->image_intro);
            } else if (isset($article_images->image_fulltext)) {
                $r['image'] = $this->imageUrl($article_images->image_fulltext);
            } else {
                $r['image'] = '';
            }

            $r['thumbnail'] = $r['image'];

            $r += array(
                'title'             => $res['comment_title'],
                'description'       => $res['comments'],
                'url'               => ContentHelperRoute::getArticleRoute($res['id'], $res['catid']),
                'url_label'         => n2_('View article'),
                'rating'            => round($res['rating'], 1),
                'name'              => $res['name'],
                'username'          => $res['username'],
                'email'             => $res['email'],
                'location'          => $res['location'],
                'creation_time'     => $res['created'],
                'vote_helpful'      => $res['vote_helpful'],
                'vote_total'        => $res['vote_total'],
                'review_note'       => $res['review_note'],
                'article_title'     => $res['title'],
                'article_introtext' => $res['introtext'],
                'article_fulltext'  => $res['fulltext'],
                'article_hits'      => $res['hits']
            );

            if (isset($article_images->image_intro)) $r['article_introtext_image'] = $this->imageUrl($article_images->image_intro);
            if (isset($article_images->image_fulltext)) $r['article_fulltext_image'] = $this->imageUrl($article_images->image_fulltext);

            $data[] = $r;
        }

        return $data;
    }

}
