<?php

namespace Nextend\SmartSlider3Pro\Generator\Joomla\Zoo\Sources;

use App;
use Nextend\Framework\Form\Container\ContainerTable;
use Nextend\Framework\Form\Element\Mixed\GeneratorOrder;
use Nextend\Framework\Form\Element\OnOff;
use Nextend\Framework\Notification\Notification;
use Nextend\Framework\Parser\Common;
use Nextend\SmartSlider3\Generator\AbstractGenerator;
use Nextend\SmartSlider3\Platform\Joomla\ImageFallback;
use Nextend\SmartSlider3Pro\Generator\Joomla\Zoo\Elements\ZooCategories;
use Nextend\SmartSlider3Pro\Generator\Joomla\Zoo\Elements\ZooTags;

class ZooItems extends AbstractGenerator {

    protected $layout = 'article';

    protected $appid, $identifier;

    public function __construct($group, $name, $label, $appid, $identifier) {
        parent::__construct($group, $name, $label);
        $this->appid      = $appid;
        $this->identifier = $identifier;
    }

    public function getDescription() {
        return sprintf(n2_('Creates slides from %1$s content.'), 'Zoo');
    }

    public function renderFields($container) {

        Notification::notice(sprintf('%s is deprecated and will be removed after %s.', 'Zoo generator', 'December 31st, 2020'));

        parent::renderFields($container);

        $filterGroup = new ContainerTable($container, 'filter', n2_('Filter'));

        $source = $filterGroup->createRow('source-row');
        new ZooCategories($source, 'zooitemssourcecategories', n2_('Category'), 0, array(
            'isMultiple' => true,
            'appid'      => $this->appid
        ));
        new ZooTags($source, 'zooitemssourcetags', n2_('Tag'), 0, array(
            'isMultiple' => true
        ));

        $limit = $filterGroup->createRow('limit-row');
        new OnOff($limit, 'zoofrontpage', n2_('Frontpage'), 0);

        $orderGroup = new ContainerTable($container, 'order-group', n2_('Order'));
        $order      = $orderGroup->createRow('order-row');
        new GeneratorOrder($order, 'zooitemsorder', 'a.created|*|desc', array(
            'options' => array(
                ''           => n2_('None'),
                'a.name'     => n2_('Name'),
                'a.hits'     => n2_('Hits'),
                'a.created'  => n2_('Creation time'),
                'a.modified' => n2_('Modification time'),
                'a.priority' => n2_('Priority')
            )
        ));
    }

    protected function _getData($count, $startIndex) {

        $data      = array();
        $appId     = $this->appid;
        $typeAlias = $this->identifier;

        require_once(JPATH_ADMINISTRATOR . DIRECTORY_SEPARATOR . 'components' . DIRECTORY_SEPARATOR . 'com_zoo' . DIRECTORY_SEPARATOR . 'config.php');
        $this->zoo = App::getInstance('zoo');

        $app   = $this->zoo->table->application->get($appId);
        $table = $this->zoo->table->item;

        $select = 'a.*';
        $from   = $table->name . ' AS a';

        $where = array();

        $where[] = 'a.application_id = ' . $appId;
        $where[] = "a.type = '" . $typeAlias . "'";
        $where[] = "a.state = 1";

        $now     = $this->zoo->date->create()
                                   ->toSQL();
        $null    = $this->zoo->database->getNullDate();
        $where[] = "(a.publish_up = '" . $null . "' OR a.publish_up < '" . $now . "')";
        $where[] = "(a.publish_down = '" . $null . "' OR a.publish_down > '" . $now . "')";

        $where[] = 'a.' . $this->zoo->user->getDBAccessString($this->zoo->user->get());

        $categories = array_map('intval', explode('||', $this->data->get('zooitemssourcecategories', '0')));
        $frontpage  = $this->data->get('zoofrontpage', '0');
        if (($categories && !in_array(0, $categories)) || $frontpage) {
            if ($frontpage) {
                $categories = array(0);
            }
            $from    .= ' LEFT JOIN ' . ZOO_TABLE_CATEGORY_ITEM . ' AS ci ON a.id = ci.item_id';
            $where[] = 'ci.category_id IN (' . implode(',', $categories) . ') ';
        }

        $tags = explode('||', $this->data->get('zooitemssourcetags', 'All'));
        if (!empty($tags[0]) && !in_array('0', $tags)) {
            $where[] = 'a.id IN (SELECT item_id FROM #__zoo_tag WHERE name IN (' . implode(',', $tags) . ')) ';
        }

        $options = array(
            'select'     => $select,
            'from'       => $from,
            'conditions' => array(implode(' AND ', $where)),
            'group'      => 'a.id',
            'offset'     => $startIndex,
            'limit'      => $count + $startIndex
        );

        $order = Common::parse($this->data->get('zooitemsorder', 'a.created|*|desc'));
        if ($order[0]) {
            $options += array(
                'order' => $order[0] . ' ' . $order[1] . ' '
            );
        }

        $items = $table->all($options);
        $i     = 0;

        $types = $app->getTypes();
        $skip  = array(
            'supercontact',
            'linkpro',
            'downloadpro',
            'joomlamodule'
        );
        foreach ($items as $item) {
            $typeElements      = $types[$typeAlias]->getElements();
            $data[$i]          = array();
            $data[$i]['title'] = $item->name;
            $data[$i]['url']   = $this->zoo->route->item($item);
            $data[$i]['hits']  = $item->hits;

            $fields = array();
            foreach ($typeElements as $k => $el) {
                $type = $el->config->get('type');
                if (in_array($type, $skip)) continue;
                $el->setItem($item);
                $name     = str_replace('-', '', $type . '_' . $k);
                $fields[] = $data[$i][$name] = @$el->render();
            }
            $data[$i]['image'] = $data[$i]['thumbnail'] = ImageFallback::fallback(array(), $fields);

            $i++;
        }

        return $data;
    }

}
